@@ -15,13 +15,13 @@
  *  along with this program; if not, write to the Free Software
  *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
  *
- *  $Id: gtkentryaction.h 3036 2008-01-13 19:32:10Z dscorgie $
+ *  $Id$
  */
 
 #ifndef GTK_ENTRY_ACTION_H
 #define GTK_ENTRY_ACTION_H
 
-#include <gtk/gtkaction.h>
+#include <gtk/gtk.h>
 
 G_BEGIN_DECLS
 
