@@ -373,10 +373,14 @@ mallard_try_run (YelpMallard *mallard,
 {
     /* We expect to be in a locked mutex when this function is called. */
     MallardPageData *page_data;
+    YelpError *error;
 
     page_data = g_hash_table_lookup (mallard->priv->pages_hash, page_id);
     if (page_data == NULL) {
-        printf ("FIXME: page not found: %s\n", page_id);
+	error = yelp_error_new (_("Page not found"),
+				_("The page %s was not found in the document %s."),
+				page_id, mallard->priv->directory);
+	yelp_document_error_page (YELP_DOCUMENT (mallard), page_id, error);
         return;
     }
 
@@ -494,12 +498,8 @@ mallard_page_data_info (MallardPageData *page_data,
         else if (xmlStrEqual (child->name, BAD_CAST "title")) {
             xmlNodePtr node, title_node;
             xmlChar *type, *role;
-            title_node = xmlNewChild (cache_node,
-                                      page_data->mallard->priv->cache_ns,
-                                      BAD_CAST "title", NULL);
-            for (node = child->children; node; node = node->next) {
-                xmlAddChild (title_node, xmlCopyNode (node, 1));
-            }
+            title_node = xmlCopyNode (child, 1);
+            xmlAddChild (cache_node, title_node);
 
             type = xmlGetProp (child, BAD_CAST "type");
             role = xmlGetProp (child, BAD_CAST "role");
@@ -508,15 +508,6 @@ mallard_page_data_info (MallardPageData *page_data,
                 page_data->link_title = TRUE;
             if (xmlStrEqual (type, BAD_CAST "sort"))
                 page_data->sort_title = TRUE;
-
-            if (type) {
-                xmlSetProp (title_node, BAD_CAST "type", BAD_CAST type);
-                xmlFree (type);
-            }
-            if (role) {
-                xmlSetProp (title_node, BAD_CAST "role", BAD_CAST type);
-                xmlFree (role);
-            }
         }
         else if (xmlStrEqual (child->name, BAD_CAST "desc") ||
                  xmlStrEqual (child->name, BAD_CAST "link")) {
